@@ -18,11 +18,11 @@ use Exporter::Tidy
 ;
 
 # ABSTRACT: Some useful pointer utilities when writing FFI modules
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 
 
-sub locate_module_share_lib (;$)
+sub locate_module_share_lib (;$$)
 {
   require Config;
   my($module, $modlibname) = @_;
@@ -42,7 +42,7 @@ sub locate_module_share_lib (;$)
 };
 
 our $ffi = FFI::Platypus->new;
-$ffi->lib(locate_module_share_lib());
+$ffi->package;
 $ffi->attach( [lookup_type => '_lookup_type'] => ['string'] => 'string');
 
 # nicked this from FFI/Raw.pm
@@ -143,7 +143,7 @@ FFI::Util - Some useful pointer utilities when writing FFI modules
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -151,6 +151,10 @@ version 0.11
 
 =head1 DESCRIPTION
 
+B<Note>: This module has largely been obsoleted by L<FFI::Platypus>, which
+I recommend that you use instead of this module.  This module may be removed
+from CPAN at a future date, but not before 31 January 2017.
+
 This module provides some useful memory manipulation that is either difficult
 or impossible in pure Perl.  It was originally intended to be used by
 L<Archive::Libarchive::FFI>, but it may be useful in other projects.
